pub struct SynParams {
pub src_ip: Ipv4Addr,
pub dst_ip: Ipv4Addr,
pub src_port: u16,
pub dst_port: u16,
pub seq: u32,
pub src_mac: [u8; 6],
pub dst_mac: [u8; 6],
pub mss: u16,
pub wscale: Option<u8>,
}Expand description
Parameters for constructing a TCP SYN frame (active open).
Used when arcbox initiates a TCP connection toward the guest for an inbound port-forward. Only the MSS option is included — WScale and SACK-Permitted are negotiated by the peer echoing them in its SYN-ACK.
Fields
src_ip: Ipv4Addrdst_ip: Ipv4Addrsrc_port: u16dst_port: u16seq: u32src_mac: [u8; 6]dst_mac: [u8; 6]mss: u16wscale: Option<u8>Trait Implementations